┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/urlnavigator.h
diff options
context:
space:
mode:
authorDavid Faure <[email protected]>2007-03-26 23:04:43 +0000
committerDavid Faure <[email protected]>2007-03-26 23:04:43 +0000
commit85bc196887fbed01187e3830cd28c2500cb01cb2 (patch)
tree98cde59002e2e1214e61a328c253ba58546bb532 /src/urlnavigator.h
parentc6bc5511a8ba05d8f44217b404d615d4d56bb53f (diff)
Ported to KBookmarkManager::closestBookmark - which even solves another TODO about code duplication.
Improved urlnavigator API to avoid exposing the full QList (api independent from implementation now). svn path=/trunk/KDE/kdebase/apps/; revision=646954
Diffstat (limited to 'src/urlnavigator.h')
-rw-r--r--src/urlnavigator.h13
1 files changed, 6 insertions, 7 deletions
diff --git a/src/urlnavigator.h b/src/urlnavigator.h
index aa46709aa..8a1d2512d 100644
--- a/src/urlnavigator.h
+++ b/src/urlnavigator.h
@@ -58,10 +58,7 @@ class ProtocolCombo;
*
* The URL navigator also remembers the URL history and allows to go
* back and forward within this history.
-*/
-
-//typedef QList<KUrl> UrlStack;
-
+ */
class UrlNavigator : public QWidget
{
Q_OBJECT
@@ -107,13 +104,16 @@ public:
/** Returns the portion of the current active URL up to the button at index. */
KUrl url(int index) const;
+ /** Returns the amount of items in the history */
+ int historySize() const;
+
/**
* Returns the complete URL history. The index 0 indicates the oldest
* history element.
* @param index Output parameter which indicates the current
* index of the location.
*/
- const QList<HistoryElem>& history(int& index) const;
+ HistoryElem currentHistoryItem() const;
/**
* Goes back one step in the URL history. The signals
@@ -315,7 +315,6 @@ private:
QLineEdit* m_host;
QLinkedList<UrlNavigatorButton*> m_navButtons;
QWidget* m_filler;
- //UrlStack m_urls;
};
#endif
@@ -107,13 +104,16 @@ public:
/**
- * Returns the complete URL history. The index 0 indicates the oldest
+ * Returns one item out of the history. The index 0 indicates the oldest
* history element.
* @param index Output parameter which indicates the current